import { readFile } from "fs/promises";
import commentJson, { assign } from "comment-json";
import { posix } from "path";
import { isRootTsConfig } from "./isRootTsConfig.js";
export class TsConfigResolver {
    cache;
    constructor() {
        this.cache = new Map();
    }
    async resolve(path) {
        if (this.cache.has(path)) {
            return this.cache.get(path);
        }
        const config = await readFile(path, "utf-8").then((data) => commentJson.parse(data));
        for (const ref of config.references || []) {
            assign(ref, {
                path: posix.join(path, "..", ref.path),
            });
        }
        this.cache.set(path, config);
        return config;
    }
    async isReferencedInRootConfig(path) {
        if (isRootTsConfig(path)) {
            return false;
        }
        const rootTsConfig = await this.resolve(posix.join(path, "..", "tsconfig.json"));
        return rootTsConfig.references?.some((ref) => ref.path === path) || false;
    }
}
//# sourceMappingURL=TsConfigResolver.js.map